@@ -8,8 +8,6 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.assets
-import aws_cdk.aws_cloudformation
 import aws_cdk.aws_cloudfront
 import aws_cdk.aws_iam
 import aws_cdk.aws_lambda
@@ -18,7 +16,7 @@ import aws_cdk.aws_s3_assets
 import aws_cdk.core
 import constructs
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-s3-deployment", "1.36.1", __name__[0:-6], "aws-s3-deployment@1.36.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-s3-deployment", "1.38.0", __name__[0:-6], "aws-s3-deployment@1.38.0.jsii.tgz")
 
 __all__ = [
     "__jsii_assembly__",
